@@ -4,5 +4,5 @@ from iupdatable.system.io.File import File
 from iupdatable.system.io.Directory import Directory
 from iupdatable.system.convert.Base64 import Base64
 from iupdatable.system.hardware.CSProduct import CSProduct
-from iupdatable.system.net.HttpWebRequest import HttpWebRequest
 from iupdatable.system.common.Status import Status
+from iupdatable.system.timer.Timer import Timer
